==> ejc-outcontract-impl-3.0.0-20230320.065545-159-sources.jar: com/ejianc/foundation/sealApproval/bean/SealApprovalEntity.java <==
package com.ejianc.foundation.sealApproval.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 用印审批
 * 
 * @author generator
 * 
 */
 @TableName("ejc_seal_approval")
public class SealApprovalEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="change_outcontract_id")
    private Long changeOutcontractId; // 变更合同id
    @TableField(value="change_reason")
    private String changeReason; // 变更原因
    @TableField(value="supplementary_agreement_name")
    private String supplementaryAgreementName; // 合同补充协议名称
    @TableField(value="after_change_amount")
    private BigDecimal afterChangeAmount; // 变更后金额
    @TableField(value="change_amount")
    private BigDecimal changeAmount; // 变更金额
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private Long projectDepartmentId; // 项目部id
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="contract_name")
    private String contractName; // 合同名称

    @TableField(value="sign_unit")
    private Long signUnit; // 签约单位
    @TableField(value="sign_unit_name")
    private String signUnitName; // 签约单位名称
    @TableField(value="apply_dept")
    private Long applyDept; // 申请部门
    @TableField(value="apply_dept_name")
    private String applyDeptName; // 申请部门名称
    @TableField(value="seal_count")
    private Integer sealCount; // 用印数量（次数）
    @TableField(value="seal_count_copy")
    private Integer sealCountCopy; // 用印数量（份数）
    @TableField(value="apply_date")
    private Date applyDate; // 申请日期
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="employee_phone")
    private String employeePhone; // 经办人联系电话
    @TableField(value="memo")
    private String memo; // 备注

    @TableField(value="contract_price")
    private BigDecimal contractPrice; // 合同额
    
    @TableField(value="print_unit")
    private Long printUnit; // 用印单位
    
    @TableField(value="print_unit_name")
    private String printUnitName; // 用印单位
    
	@TableField(value = "print_time")
	private Date printTime;	//用印时间

    @TableField(value="print_state")
    private String printState; // 1：已用印，0未用印
    
    @TableField(value="out_date")
    private Date outDate; // 借出日期
    @TableField(value="return_date")
    private Date returnDate; // 归还日期
    @TableField(value="seal_reasons")
    private String sealReasons; // 用印事由
    @TableField(value="bid")
    private String bid; // 投标
    @TableField(value="certification")
    private String certification; // 资格审查
    @TableField(value="contract")
    private String contract; // 合同
    @TableField(value="lawsuit")
    private String lawsuit; // 诉讼
    @TableField(value="prove")
    private String prove; // 证明
    @TableField(value="guarantee")
    private String guarantee; // 担保
    @TableField(value="excellence")
    private String excellence; // 创优
    @TableField(value="engineering")
    private String engineering; // 工程资料
    @TableField(value="company_seal")
    private String companySeal; // 公司章
    @TableField(value="legal_seal")
    private String legalSeal; // 法人代表章
    @TableField(value="contract_seal")
    private String contractSeal; // 合同专用章
    @TableField(value="party_seal")
    private String partySeal; // 党委章
    @TableField(value="discipline_seal")
    private String disciplineSeal; // 纪委章
    @TableField(value="other_seal")
    private String otherSeal; // 其他章
    @TableField(value="seal_memo")
    private String sealMemo; // 其他章备注
    @TableField(value="signed")
    private String signed; // 签约
    @TableField(value="others")
    private String others; // 其他
    @TableField(value = "seal_content")
    private String sealContent;//用印内容
    @TableField(value = "stamp_category")
    private String stampCategory;//印章种类;
    @TableField(value="contract_type")
    private String contractType; // 合同类型
    @TableField(value="seal_lend")
    private String sealLend; // 印章借出
    
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public Long getApplyDept() {
        return applyDept;
    }

    public void setApplyDept(Long applyDept) {
        this.applyDept = applyDept;
    }
    public String getApplyDeptName() {
        return applyDeptName;
    }

    public void setApplyDeptName(String applyDeptName) {
        this.applyDeptName = applyDeptName;
    }
    public Integer getSealCount() {
		return sealCount;
	}

	public void setSealCount(Integer sealCount) {
		this.sealCount = sealCount;
	}

	public Integer getSealCountCopy() {
		return sealCountCopy;
	}

	public void setSealCountCopy(Integer sealCountCopy) {
		this.sealCountCopy = sealCountCopy;
	}

	public Date getApplyDate() {
        return applyDate;
    }

    public void setApplyDate(Date applyDate) {
        this.applyDate = applyDate;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public String getEmployeePhone() {
        return employeePhone;
    }

    public void setEmployeePhone(String employeePhone) {
        this.employeePhone = employeePhone;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Date getOutDate() {
        return outDate;
    }

    public void setOutDate(Date outDate) {
        this.outDate = outDate;
    }
    public Date getReturnDate() {
        return returnDate;
    }

    public void setReturnDate(Date returnDate) {
        this.returnDate = returnDate;
    }
    public String getSealReasons() {
        return sealReasons;
    }

    public void setSealReasons(String sealReasons) {
        this.sealReasons = sealReasons;
    }
    public String getBid() {
        return bid;
    }

    public void setBid(String bid) {
        this.bid = bid;
    }
    public String getCertification() {
        return certification;
    }

    public void setCertification(String certification) {
        this.certification = certification;
    }
    public String getContract() {
        return contract;
    }

    public void setContract(String contract) {
        this.contract = contract;
    }
    public String getLawsuit() {
        return lawsuit;
    }

    public void setLawsuit(String lawsuit) {
        this.lawsuit = lawsuit;
    }
    public String getProve() {
        return prove;
    }

    public void setProve(String prove) {
        this.prove = prove;
    }
    public String getGuarantee() {
        return guarantee;
    }

    public void setGuarantee(String guarantee) {
        this.guarantee = guarantee;
    }
    public String getExcellence() {
        return excellence;
    }

    public void setExcellence(String excellence) {
        this.excellence = excellence;
    }
    public String getEngineering() {
        return engineering;
    }

    public void setEngineering(String engineering) {
        this.engineering = engineering;
    }
    public String getCompanySeal() {
        return companySeal;
    }

    public void setCompanySeal(String companySeal) {
        this.companySeal = companySeal;
    }
    public String getLegalSeal() {
        return legalSeal;
    }

    public void setLegalSeal(String legalSeal) {
        this.legalSeal = legalSeal;
    }
    public String getContractSeal() {
        return contractSeal;
    }

    public void setContractSeal(String contractSeal) {
        this.contractSeal = contractSeal;
    }
    public String getPartySeal() {
        return partySeal;
    }

    public void setPartySeal(String partySeal) {
        this.partySeal = partySeal;
    }
    public String getDisciplineSeal() {
        return disciplineSeal;
    }

    public void setDisciplineSeal(String disciplineSeal) {
        this.disciplineSeal = disciplineSeal;
    }
    public String getOtherSeal() {
        return otherSeal;
    }

    public void setOtherSeal(String otherSeal) {
        this.otherSeal = otherSeal;
    }

    public String getSealMemo() {
        return sealMemo;
    }

    public void setSealMemo(String sealMemo) {
        this.sealMemo = sealMemo;
    }

    public String getSigned() {
        return signed;
    }

    public void setSigned(String signed) {
        this.signed = signed;
    }
    public String getOthers() {
        return others;
    }

    public void setOthers(String others) {
        this.others = others;
    }

    public String getSealContent() {
        return sealContent;
    }

    public void setSealContent(String sealContent) {
        this.sealContent = sealContent;
    }

    public String getStampCategory() {
        return stampCategory;
    }

    public void setStampCategory(String stampCategory) {
        this.stampCategory = stampCategory;
    }

    public String getContractType() {
        return contractType;
    }

    public void setContractType(String contractType) {
        this.contractType = contractType;
    }

	public String getSealLend() {
		return sealLend;
	}

	public void setSealLend(String sealLend) {
		this.sealLend = sealLend;
	}

	public BigDecimal getContractPrice() {
		return contractPrice;
	}

	public void setContractPrice(BigDecimal contractPrice) {
		this.contractPrice = contractPrice;
	}

	public Long getPrintUnit() {
		return printUnit;
	}

	public void setPrintUnit(Long printUnit) {
		this.printUnit = printUnit;
	}

	public String getPrintUnitName() {
		return printUnitName;
	}

	public void setPrintUnitName(String printUnitName) {
		this.printUnitName = printUnitName;
	}

	public Date getPrintTime() {
		return printTime;
	}

	public void setPrintTime(Date printTime) {
		this.printTime = printTime;
	}

	public String getPrintState() {
		return printState;
	}

	public void setPrintState(String printState) {
		this.printState = printState;
	}

    public Long getChangeOutcontractId() {
        return changeOutcontractId;
    }

    public void setChangeOutcontractId(Long changeOutcontractId) {
        this.changeOutcontractId = changeOutcontractId;
    }

    public String getChangeReason() {
        return changeReason;
    }

    public void setChangeReason(String changeReason) {
        this.changeReason = changeReason;
    }

    public String getSupplementaryAgreementName() {
        return supplementaryAgreementName;
    }

    public void setSupplementaryAgreementName(String supplementaryAgreementName) {
        this.supplementaryAgreementName = supplementaryAgreementName;
    }

    public BigDecimal getAfterChangeAmount() {
        return afterChangeAmount;
    }

    public void setAfterChangeAmount(BigDecimal afterChangeAmount) {
        this.afterChangeAmount = afterChangeAmount;
    }

    public BigDecimal getChangeAmount() {
        return changeAmount;
    }

    public void setChangeAmount(BigDecimal changeAmount) {
        this.changeAmount = changeAmount;
    }

    public Long getSignUnit() {
        return signUnit;
    }

    public void setSignUnit(Long signUnit) {
        this.signUnit = signUnit;
    }

    public String getSignUnitName() {
        return signUnitName;
    }

    public void setSignUnitName(String signUnitName) {
        this.signUnitName = signUnitName;
    }
}

==> ejc-outcontract-impl-3.0.0-20241011.022113-232-sources.jar: com/ejianc/foundation/sealApproval/bean/SealApprovalEntity.java <==
package com.ejianc.foundation.sealApproval.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 用印审批
 * 
 * @author generator
 * 
 */
 @TableName("ejc_seal_approval")
public class SealApprovalEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="change_outcontract_id")
    private Long changeOutcontractId; // 变更合同id
    @TableField(value="change_reason")
    private String changeReason; // 变更原因
    @TableField(value="supplementary_agreement_name")
    private String supplementaryAgreementName; // 合同补充协议名称
    @TableField(value="after_change_amount")
    private BigDecimal afterChangeAmount; // 变更后金额
    @TableField(value="change_amount")
    private BigDecimal changeAmount; // 变更金额
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private Long projectDepartmentId; // 项目部id
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="supplier")
    private Long supplier; // 供方单位
    @TableField(value="supplier_name")
    private String supplierName; // 分供商名称

    @TableField(value="sign_unit")
    private Long signUnit; // 签约单位
    @TableField(value="sign_unit_name")
    private String signUnitName; // 签约单位名称
    @TableField(value="apply_dept")
    private Long applyDept; // 申请部门
    @TableField(value="apply_dept_name")
    private String applyDeptName; // 申请部门名称
    @TableField(value="seal_count")
    private Integer sealCount; // 用印数量（次数）
    @TableField(value="seal_count_copy")
    private Integer sealCountCopy; // 用印数量（份数）
    @TableField(value="apply_date")
    private Date applyDate; // 申请日期
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="employee_phone")
    private String employeePhone; // 经办人联系电话
    @TableField(value="memo")
    private String memo; // 备注

    @TableField(value="contract_price")
    private BigDecimal contractPrice; // 合同额
    
    @TableField(value="print_unit")
    private Long printUnit; // 用印单位
    
    @TableField(value="print_unit_name")
    private String printUnitName; // 用印单位
    
	@TableField(value = "print_time")
	private Date printTime;	//用印时间

    @TableField(value="print_state")
    private String printState; // 1：已用印，0未用印
    
    @TableField(value="out_date")
    private Date outDate; // 借出日期
    @TableField(value="return_date")
    private Date returnDate; // 归还日期
    @TableField(value="seal_reasons")
    private String sealReasons; // 用印事由
    @TableField(value="bid")
    private String bid; // 投标
    @TableField(value="certification")
    private String certification; // 资格审查
    @TableField(value="contract")
    private String contract; // 合同
    @TableField(value="lawsuit")
    private String lawsuit; // 诉讼
    @TableField(value="prove")
    private String prove; // 证明
    @TableField(value="guarantee")
    private String guarantee; // 担保
    @TableField(value="excellence")
    private String excellence; // 创优
    @TableField(value="engineering")
    private String engineering; // 工程资料
    @TableField(value="company_seal")
    private String companySeal; // 公司章
    @TableField(value="legal_seal")
    private String legalSeal; // 法人代表章
    @TableField(value="contract_seal")
    private String contractSeal; // 合同专用章
    @TableField(value="party_seal")
    private String partySeal; // 党委章
    @TableField(value="discipline_seal")
    private String disciplineSeal; // 纪委章
    @TableField(value="other_seal")
    private String otherSeal; // 其他章
    @TableField(value="seal_memo")
    private String sealMemo; // 其他章备注
    @TableField(value="signed")
    private String signed; // 签约
    @TableField(value="others")
    private String others; // 其他
    @TableField(value = "seal_content")
    private String sealContent;//用印内容
    @TableField(value = "stamp_category")
    private String stampCategory;//印章种类;
    @TableField(value="contract_type")
    private String contractType; // 合同类型
    @TableField(value="seal_lend")
    private String sealLend; // 印章借出

    @TableField(value="submit_date")
    private Date submitDate; // 提交日期
    @TableField(value="submiter")
    private String submiter; // 提交人
    
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public Long getApplyDept() {
        return applyDept;
    }

    public void setApplyDept(Long applyDept) {
        this.applyDept = applyDept;
    }
    public String getApplyDeptName() {
        return applyDeptName;
    }

    public void setApplyDeptName(String applyDeptName) {
        this.applyDeptName = applyDeptName;
    }
    public Integer getSealCount() {
		return sealCount;
	}

	public void setSealCount(Integer sealCount) {
		this.sealCount = sealCount;
	}

	public Integer getSealCountCopy() {
		return sealCountCopy;
	}

	public void setSealCountCopy(Integer sealCountCopy) {
		this.sealCountCopy = sealCountCopy;
	}

	public Date getApplyDate() {
        return applyDate;
    }

    public void setApplyDate(Date applyDate) {
        this.applyDate = applyDate;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public String getEmployeePhone() {
        return employeePhone;
    }

    public void setEmployeePhone(String employeePhone) {
        this.employeePhone = employeePhone;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Date getOutDate() {
        return outDate;
    }

    public void setOutDate(Date outDate) {
        this.outDate = outDate;
    }
    public Date getReturnDate() {
        return returnDate;
    }

    public void setReturnDate(Date returnDate) {
        this.returnDate = returnDate;
    }
    public String getSealReasons() {
        return sealReasons;
    }

    public void setSealReasons(String sealReasons) {
        this.sealReasons = sealReasons;
    }
    public String getBid() {
        return bid;
    }

    public void setBid(String bid) {
        this.bid = bid;
    }
    public String getCertification() {
        return certification;
    }

    public void setCertification(String certification) {
        this.certification = certification;
    }
    public String getContract() {
        return contract;
    }

    public void setContract(String contract) {
        this.contract = contract;
    }
    public String getLawsuit() {
        return lawsuit;
    }

    public void setLawsuit(String lawsuit) {
        this.lawsuit = lawsuit;
    }
    public String getProve() {
        return prove;
    }

    public void setProve(String prove) {
        this.prove = prove;
    }
    public String getGuarantee() {
        return guarantee;
    }

    public void setGuarantee(String guarantee) {
        this.guarantee = guarantee;
    }
    public String getExcellence() {
        return excellence;
    }

    public void setExcellence(String excellence) {
        this.excellence = excellence;
    }
    public String getEngineering() {
        return engineering;
    }

    public void setEngineering(String engineering) {
        this.engineering = engineering;
    }
    public String getCompanySeal() {
        return companySeal;
    }

    public void setCompanySeal(String companySeal) {
        this.companySeal = companySeal;
    }
    public String getLegalSeal() {
        return legalSeal;
    }

    public void setLegalSeal(String legalSeal) {
        this.legalSeal = legalSeal;
    }
    public String getContractSeal() {
        return contractSeal;
    }

    public void setContractSeal(String contractSeal) {
        this.contractSeal = contractSeal;
    }
    public String getPartySeal() {
        return partySeal;
    }

    public void setPartySeal(String partySeal) {
        this.partySeal = partySeal;
    }
    public String getDisciplineSeal() {
        return disciplineSeal;
    }

    public void setDisciplineSeal(String disciplineSeal) {
        this.disciplineSeal = disciplineSeal;
    }
    public String getOtherSeal() {
        return otherSeal;
    }

    public void setOtherSeal(String otherSeal) {
        this.otherSeal = otherSeal;
    }

    public String getSealMemo() {
        return sealMemo;
    }

    public void setSealMemo(String sealMemo) {
        this.sealMemo = sealMemo;
    }

    public String getSigned() {
        return signed;
    }

    public void setSigned(String signed) {
        this.signed = signed;
    }
    public String getOthers() {
        return others;
    }

    public void setOthers(String others) {
        this.others = others;
    }

    public String getSealContent() {
        return sealContent;
    }

    public void setSealContent(String sealContent) {
        this.sealContent = sealContent;
    }

    public String getStampCategory() {
        return stampCategory;
    }

    public void setStampCategory(String stampCategory) {
        this.stampCategory = stampCategory;
    }

    public String getContractType() {
        return contractType;
    }

    public void setContractType(String contractType) {
        this.contractType = contractType;
    }

	public String getSealLend() {
		return sealLend;
	}

	public void setSealLend(String sealLend) {
		this.sealLend = sealLend;
	}

	public BigDecimal getContractPrice() {
		return contractPrice;
	}

	public void setContractPrice(BigDecimal contractPrice) {
		this.contractPrice = contractPrice;
	}

	public Long getPrintUnit() {
		return printUnit;
	}

	public void setPrintUnit(Long printUnit) {
		this.printUnit = printUnit;
	}

	public String getPrintUnitName() {
		return printUnitName;
	}

	public void setPrintUnitName(String printUnitName) {
		this.printUnitName = printUnitName;
	}

	public Date getPrintTime() {
		return printTime;
	}

	public void setPrintTime(Date printTime) {
		this.printTime = printTime;
	}

	public String getPrintState() {
		return printState;
	}

	public void setPrintState(String printState) {
		this.printState = printState;
	}

    public Long getChangeOutcontractId() {
        return changeOutcontractId;
    }

    public void setChangeOutcontractId(Long changeOutcontractId) {
        this.changeOutcontractId = changeOutcontractId;
    }

    public String getChangeReason() {
        return changeReason;
    }

    public void setChangeReason(String changeReason) {
        this.changeReason = changeReason;
    }

    public String getSupplementaryAgreementName() {
        return supplementaryAgreementName;
    }

    public void setSupplementaryAgreementName(String supplementaryAgreementName) {
        this.supplementaryAgreementName = supplementaryAgreementName;
    }

    public BigDecimal getAfterChangeAmount() {
        return afterChangeAmount;
    }

    public void setAfterChangeAmount(BigDecimal afterChangeAmount) {
        this.afterChangeAmount = afterChangeAmount;
    }

    public BigDecimal getChangeAmount() {
        return changeAmount;
    }

    public void setChangeAmount(BigDecimal changeAmount) {
        this.changeAmount = changeAmount;
    }

    public Long getSignUnit() {
        return signUnit;
    }

    public void setSignUnit(Long signUnit) {
        this.signUnit = signUnit;
    }

    public String getSignUnitName() {
        return signUnitName;
    }

    public void setSignUnitName(String signUnitName) {
        this.signUnitName = signUnitName;
    }

    public Date getSubmitDate() {
        return submitDate;
    }

    public void setSubmitDate(Date submitDate) {
        this.submitDate = submitDate;
    }

    public String getSubmiter() {
        return submiter;
    }

    public void setSubmiter(String submiter) {
        this.submiter = submiter;
    }

    public Long getSupplier() {
        return supplier;
    }

    public void setSupplier(Long supplier) {
        this.supplier = supplier;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
}
